@@ -10,8 +10,8 @@ import (
 func TestClusterRoleRender(t *testing.T) {
 	c := render.ClusterRole{}
 	r := render.NewRow(2)
-	c.Render(load(t, "cr"), "-", &r)
 
+	assert.NoError(t, c.Render(load(t, "cr"), "-", &r))
 	assert.Equal(t, "-/blee", r.ID)
 	assert.Equal(t, render.Fields{"blee"}, r.Fields[:1])
 }
