@@ -56,7 +56,7 @@ func (r ReplicaSet) Render(o interface{}, ns string, row *Row) error {
 		strconv.Itoa(int(rs.Status.ReadyReplicas)),
 		mapToStr(rs.Labels),
 		asStatus(r.diagnose(rs)),
-		toAge(rs.ObjectMeta.CreationTimestamp),
+		toAge(rs.GetCreationTimestamp()),
 	}
 
 	return nil
