@@ -10,7 +10,7 @@ import (
 	"github.com/derailed/tview"
 )
 
-// ShowConfirm pops a confirmation dialog.
+// ShowError pops an error dialog.
 func ShowError(styles config.Dialog, pages *ui.Pages, msg string) {
 	f := tview.NewForm()
 	f.SetItemPadding(0)
@@ -20,7 +20,7 @@ func ShowError(styles config.Dialog, pages *ui.Pages, msg string) {
 		SetLabelColor(styles.LabelFgColor.Color()).
 		SetFieldTextColor(tcell.ColorIndianRed)
 	f.AddButton("Dismiss", func() {
-		dismissError(pages)
+		dismiss(pages)
 	})
 	if b := f.GetButton(0); b != nil {
 		b.SetBackgroundColorActivated(styles.ButtonFocusBgColor.Color())
@@ -31,14 +31,10 @@ func ShowError(styles config.Dialog, pages *ui.Pages, msg string) {
 	modal.SetText(cowTalk(msg))
 	modal.SetTextColor(tcell.ColorOrangeRed)
 	modal.SetDoneFunc(func(int, string) {
-		dismissError(pages)
+		dismiss(pages)
 	})
-	pages.AddPage(confirmKey, modal, false, false)
-	pages.ShowPage(confirmKey)
-}
-
-func dismissError(pages *ui.Pages) {
-	pages.RemovePage(confirmKey)
+	pages.AddPage(dialogKey, modal, false, false)
+	pages.ShowPage(dialogKey)
 }
 
 func cowTalk(says string) string {
