@@ -3,6 +3,7 @@ package view
 import (
 	"context"
 	"fmt"
+	"io"
 	"strings"
 
 	"github.com/derailed/k9s/internal/config"
@@ -159,6 +160,10 @@ func (d *Details) Update(buff string) *Details {
 	return d
 }
 
+func (d *Details) GetWriter() io.Writer {
+	return d.text
+}
+
 // SetSubject updates the subject.
 func (d *Details) SetSubject(s string) {
 	d.subject = s
