@@ -3,7 +3,6 @@ package view
 import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/dao"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 )
 
@@ -25,7 +24,6 @@ func NewDaemonSet(gvr client.GVR) ResourceViewer {
 	}
 	d.AddBindKeysFn(d.bindKeys)
 	d.GetTable().SetEnterFn(d.showPods)
-	d.GetTable().SetColorerFn(render.DaemonSet{}.ColorerFunc())
 
 	return &d
 }
